@@ -23,6 +23,7 @@ __all__ = [
 # CG Coefficients
 #-----------------------------------------------------------------------------
 
+
 class Wigner3j(Expr):
     """Class for the Wigner-3j symbols
 
@@ -64,7 +65,7 @@ class Wigner3j(Expr):
     is_commutative = True
 
     def __new__(cls, j1, m1, j2, m2, j3, m3):
-        args = map(sympify, (j1,m1,j2,m2,j3,m3))
+        args = map(sympify, (j1, m1, j2, m2, j3, m3))
         return Expr.__new__(cls, *args)
 
     @property
@@ -97,8 +98,8 @@ class Wigner3j(Expr):
 
     # This is modified from the _print_Matrix method
     def _pretty(self, printer, *args):
-        m = ((printer._print(self.j1), printer._print(self.m1)), \
-            (printer._print(self.j2), printer._print(self.m2)), \
+        m = ((printer._print(self.j1), printer._print(self.m1)),
+            (printer._print(self.j2), printer._print(self.m2)),
             (printer._print(self.j3), printer._print(self.m3)))
         hsep = 2
         vsep = 1
@@ -111,7 +112,7 @@ class Wigner3j(Expr):
             for j in range(3):
                 s = m[j][i]
                 wdelta = maxw[j] - s.width()
-                wleft  = wdelta //2
+                wleft = wdelta //2
                 wright = wdelta - wleft
 
                 s = prettyForm(*s.right(' '*wright))
@@ -132,9 +133,10 @@ class Wigner3j(Expr):
         return D
 
     def _latex(self, printer, *args):
-        label = map(printer._print, (self.j1, self.j2, self.j3, self.m1, self.m2, self.m3))
+        label = map(printer._print, (self.j1, self.j2, self.j3,
+                    self.m1, self.m2, self.m3))
         return r'\left(\begin{array}{ccc} %s & %s & %s \\ %s & %s & %s \end{array}\right)' % \
-                tuple(label)
+            tuple(label)
 
     def doit(self, **hints):
         if self.is_symbolic:
@@ -187,10 +189,11 @@ class CG(Wigner3j):
     def doit(self, **hints):
         if self.is_symbolic:
             raise ValueError("Coefficients must be numerical")
-        return clebsch_gordan(self.j1,self.j2, self.j3, self.m1, self.m2, self.m3)
+        return clebsch_gordan(self.j1, self.j2, self.j3, self.m1, self.m2, self.m3)
 
     def _pretty(self, printer, *args):
-        bot = printer._print_seq((self.j1, self.m1, self.j2, self.m2), delimiter=',')
+        bot = printer._print_seq(
+            (self.j1, self.m1, self.j2, self.m2), delimiter=',')
         top = printer._print_seq((self.j3, self.m3), delimiter=',')
 
         pad = max(top.width(), bot.width())
@@ -198,16 +201,17 @@ class CG(Wigner3j):
         top = prettyForm(*top.left(' '))
 
         if not pad == bot.width():
-            bot = prettyForm(*bot.right(' ' * (pad-bot.width())))
+            bot = prettyForm(*bot.right(' ' * (pad - bot.width())))
         if not pad == top.width():
-            top = prettyForm(*top.right(' ' * (pad-top.width())))
+            top = prettyForm(*top.right(' ' * (pad - top.width())))
         s = stringPict('C' + ' '*pad)
         s = prettyForm(*s.below(bot))
         s = prettyForm(*s.above(top))
         return s
 
     def _latex(self, printer, *args):
-        label = map(printer._print, (self.j3, self.m3, self.j1, self.m1, self.j2, self.m2))
+        label = map(printer._print, (self.j3, self.m3, self.j1,
+                    self.m1, self.j2, self.m2))
         return r'C^{%s,%s}_{%s,%s,%s,%s}' % tuple(label)
 
 
@@ -221,7 +225,7 @@ class Wigner6j(Expr):
 
     """
     def __new__(cls, j1, j2, j12, j3, j, j23):
-        args = map(sympify, (j1,j2,j12,j3,j,j23))
+        args = map(sympify, (j1, j2, j12, j3, j, j23))
         return Expr.__new__(cls, *args)
 
     @property
@@ -254,8 +258,8 @@ class Wigner6j(Expr):
 
     # This is modified from the _print_Matrix method
     def _pretty(self, printer, *args):
-        m = ((printer._print(self.j1), printer._print(self.j3)), \
-            (printer._print(self.j2), printer._print(self.j)), \
+        m = ((printer._print(self.j1), printer._print(self.j3)),
+            (printer._print(self.j2), printer._print(self.j)),
             (printer._print(self.j12), printer._print(self.j23)))
         hsep = 2
         vsep = 1
@@ -268,7 +272,7 @@ class Wigner6j(Expr):
             for j in range(3):
                 s = m[j][i]
                 wdelta = maxw[j] - s.width()
-                wleft  = wdelta //2
+                wleft = wdelta //2
                 wright = wdelta - wleft
 
                 s = prettyForm(*s.right(' '*wright))
@@ -289,9 +293,10 @@ class Wigner6j(Expr):
         return D
 
     def _latex(self, printer, *args):
-        label = map(printer._print, (self.j1, self.j2, self.j12, self.j3, self.j, self.j23))
+        label = map(printer._print, (self.j1, self.j2, self.j12,
+                    self.j3, self.j, self.j23))
         return r'\left\{\begin{array}{ccc} %s & %s & %s \\ %s & %s & %s \end{array}\right\}' % \
-                tuple(label)
+            tuple(label)
 
     def doit(self, **hints):
         if self.is_symbolic:
@@ -309,7 +314,7 @@ class Wigner9j(Expr):
 
     """
     def __new__(cls, j1, j2, j12, j3, j4, j34, j13, j24, j):
-        args = map(sympify, (j1,j2, j12, j3, j4, j34, j13, j24, j))
+        args = map(sympify, (j1, j2, j12, j3, j4, j34, j13, j24, j))
         return Expr.__new__(cls, *args)
 
     @property
@@ -354,8 +359,11 @@ class Wigner9j(Expr):
 
     # This is modified from the _print_Matrix method
     def _pretty(self, printer, *args):
-        m = ((printer._print(self.j1), printer._print(self.j3), printer._print(self.j13)), \
-            (printer._print(self.j2), printer._print(self.j4), printer._print(self.j24)), \
+        m = (
+            (printer._print(
+                self.j1), printer._print(self.j3), printer._print(self.j13)),
+            (printer._print(
+                self.j2), printer._print(self.j4), printer._print(self.j24)),
             (printer._print(self.j12), printer._print(self.j34), printer._print(self.j)))
         hsep = 2
         vsep = 1
@@ -368,7 +376,7 @@ class Wigner9j(Expr):
             for j in range(3):
                 s = m[j][i]
                 wdelta = maxw[j] - s.width()
-                wleft  = wdelta //2
+                wleft = wdelta //2
                 wright = wdelta - wleft
 
                 s = prettyForm(*s.right(' '*wright))
@@ -392,7 +400,7 @@ class Wigner9j(Expr):
         label = map(printer._print, (self.j1, self.j2, self.j12, self.j3,
                 self.j4, self.j34, self.j13, self.j24, self.j))
         return r'\left\{\begin{array}{ccc} %s & %s & %s \\ %s & %s & %s \\ %s & %s & %s \end{array}\right\}' % \
-                tuple(label)
+            tuple(label)
 
     def doit(self, **hints):
         if self.is_symbolic:
@@ -482,71 +490,75 @@ def _cg_simp_add(e):
     other_part.append(other)
     cg_part, other = _check_varsh_872_9(cg_part)
     other_part.append(other)
-    return Add(*cg_part)+Add(*other_part)
+    return Add(*cg_part) + Add(*other_part)
+
 
 def _check_varsh_871_1(term_list):
     # Sum( CG(a,alpha,b,0,a,alpha), (alpha, -a, a)) == KroneckerDelta(b,0)
-    a,alpha,b,lt = map(Wild,('a','alpha','b','lt'))
-    expr = lt*CG(a,alpha,b,0,a,alpha)
-    simp = (2*a+1)*KroneckerDelta(b,0)
+    a, alpha, b, lt = map(Wild, ('a', 'alpha', 'b', 'lt'))
+    expr = lt*CG(a, alpha, b, 0, a, alpha)
+    simp = (2*a + 1)*KroneckerDelta(b, 0)
     sign = lt/abs(lt)
-    build_expr = 2*a+1
-    index_expr = a+alpha
-    return _check_cg_simp(expr, simp, sign, lt, term_list, (a,alpha,b,lt), (a,b), build_expr, index_expr)
+    build_expr = 2*a + 1
+    index_expr = a + alpha
+    return _check_cg_simp(expr, simp, sign, lt, term_list, (a, alpha, b, lt), (a, b), build_expr, index_expr)
 
 
 def _check_varsh_871_2(term_list):
     # Sum((-1)**(a-alpha)*CG(a,alpha,a,-alpha,c,0),(alpha,-a,a))
-    a,alpha,c,lt = map(Wild,('a','alpha','c','lt'))
-    expr = lt*CG(a,alpha,a,-alpha,c,0)
-    simp = sqrt(2*a+1)*KroneckerDelta(c,0)
-    sign = (-1)**(a-alpha)*lt/abs(lt)
-    build_expr = 2*a+1
-    index_expr = a+alpha
-    return _check_cg_simp(expr, simp, sign, lt, term_list, (a,alpha,c,lt), (a,c), build_expr, index_expr)
+    a, alpha, c, lt = map(Wild, ('a', 'alpha', 'c', 'lt'))
+    expr = lt*CG(a, alpha, a, -alpha, c, 0)
+    simp = sqrt(2*a + 1)*KroneckerDelta(c, 0)
+    sign = (-1)**(a - alpha)*lt/abs(lt)
+    build_expr = 2*a + 1
+    index_expr = a + alpha
+    return _check_cg_simp(expr, simp, sign, lt, term_list, (a, alpha, c, lt), (a, c), build_expr, index_expr)
+
 
 def _check_varsh_872_9(term_list):
     # Sum( CG(a,alpha,b,beta,c,gamma)*CG(a,alpha',b,beta',c,gamma), (gamma, -c, c), (c, abs(a-b), a+b))
-    a,alpha,alphap,b,beta,betap,c,gamma,lt = map(Wild, ('a','alpha','alphap','b','beta','betap','c','gamma','lt'))
+    a, alpha, alphap, b, beta, betap, c, gamma, lt = map(Wild, (
+        'a', 'alpha', 'alphap', 'b', 'beta', 'betap', 'c', 'gamma', 'lt'))
     # Case alpha==alphap, beta==betap
 
     # For numerical alpha,beta
-    expr = lt*CG(a,alpha,b,beta,c,gamma)**2
+    expr = lt*CG(a, alpha, b, beta, c, gamma)**2
     simp = 1
     sign = lt/abs(lt)
-    x = abs(a-b)
-    y = abs(alpha+beta)
-    build_expr = a+b+1-Piecewise((x,x>y),(0,Eq(x,y)),(y,y>x))
-    index_expr = a+b-c
-    term_list, other1 = _check_cg_simp(expr, simp, sign, lt, term_list, (a,alpha,b,beta,c,gamma,lt), (a,alpha,b,beta), build_expr, index_expr)
+    x = abs(a - b)
+    y = abs(alpha + beta)
+    build_expr = a + b + 1 - Piecewise((x, x > y), (0, Eq(x, y)), (y, y > x))
+    index_expr = a + b - c
+    term_list, other1 = _check_cg_simp(expr, simp, sign, lt, term_list, (a, alpha, b, beta, c, gamma, lt), (a, alpha, b, beta), build_expr, index_expr)
 
     # For symbolic alpha,beta
-    x = abs(a-b)
-    y = a+b
-    build_expr = (y+1-x)*(x+y+1)
-    index_expr = (c-x)*(x+c)+c+gamma
-    term_list, other2 = _check_cg_simp(expr, simp, sign, lt, term_list, (a,alpha,b,beta,c,gamma,lt), (a,alpha,b,beta), build_expr, index_expr)
+    x = abs(a - b)
+    y = a + b
+    build_expr = (y + 1 - x)*(x + y + 1)
+    index_expr = (c - x)*(x + c) + c + gamma
+    term_list, other2 = _check_cg_simp(expr, simp, sign, lt, term_list, (a, alpha, b, beta, c, gamma, lt), (a, alpha, b, beta), build_expr, index_expr)
 
     # Case alpha!=alphap or beta!=betap
     # Note: this only works with leading term of 1, pattern matching is unable to match when there is a Wild leading term
     # For numerical alpha,alphap,beta,betap
-    expr = CG(a,alpha,b,beta,c,gamma)*CG(a,alphap,b,betap,c,gamma)
-    simp = KroneckerDelta(alpha,alphap)*KroneckerDelta(beta,betap)
+    expr = CG(a, alpha, b, beta, c, gamma)*CG(a, alphap, b, betap, c, gamma)
+    simp = KroneckerDelta(alpha, alphap)*KroneckerDelta(beta, betap)
     sign = sympify(1)
-    x = abs(a-b)
-    y = abs(alpha+beta)
-    build_expr = a+b+1-Piecewise((x,x>y),(0,Eq(x,y)),(y,y>x))
-    index_expr = a+b-c
-    term_list, other3 = _check_cg_simp(expr, simp, sign, sympify(1), term_list, (a,alpha,alphap,b,beta,betap,c,gamma), (a,alpha,alphap,b,beta,betap), build_expr, index_expr)
+    x = abs(a - b)
+    y = abs(alpha + beta)
+    build_expr = a + b + 1 - Piecewise((x, x > y), (0, Eq(x, y)), (y, y > x))
+    index_expr = a + b - c
+    term_list, other3 = _check_cg_simp(expr, simp, sign, sympify(1), term_list, (a, alpha, alphap, b, beta, betap, c, gamma), (a, alpha, alphap, b, beta, betap), build_expr, index_expr)
 
     # For symbolic alpha,alphap,beta,betap
-    x = abs(a-b)
-    y = a+b
-    build_expr = (y+1-x)*(x+y+1)
-    index_expr = (c-x)*(x+c)+c+gamma
-    term_list, other4 = _check_cg_simp(expr, simp, sign, sympify(1), term_list, (a,alpha,alphap,b,beta,betap,c,gamma), (a,alpha,alphap,b,beta,betap), build_expr, index_expr)
+    x = abs(a - b)
+    y = a + b
+    build_expr = (y + 1 - x)*(x + y + 1)
+    index_expr = (c - x)*(x + c) + c + gamma
+    term_list, other4 = _check_cg_simp(expr, simp, sign, sympify(1), term_list, (a, alpha, alphap, b, beta, betap, c, gamma), (a, alpha, alphap, b, beta, betap), build_expr, index_expr)
+
+    return term_list, other1 + other2 + other4
 
-    return term_list, other1+other2+other4
 
 def _check_cg_simp(expr, simp, sign, lt, term_list, variables, dep_variables, build_index_expr, index_expr):
     """ Checks for simplifications that can be made, returning a tuple of the
@@ -599,15 +611,15 @@ def _check_cg_simp(expr, simp, sign, lt, term_list, variables, dep_variables, bu
         if not sympify(build_index_expr.subs(sub_1)).is_number:
             i += 1
             continue
-        sub_dep = [(x,sub_1[x]) for x in dep_variables]
+        sub_dep = [(x, sub_1[x]) for x in dep_variables]
         cg_index = [None] * build_index_expr.subs(sub_1)
-        for j in range(i,len(term_list)):
-            sub_2 = _check_cg(term_list[j], expr.subs(sub_dep), len(variables)-len(dep_variables), sign=(sign.subs(sub_1),sign.subs(sub_dep)))
+        for j in range(i, len(term_list)):
+            sub_2 = _check_cg(term_list[j], expr.subs(sub_dep), len(variables) - len(dep_variables), sign=(sign.subs(sub_1), sign.subs(sub_dep)))
             if sub_2 is None:
                 continue
             if not sympify(index_expr.subs(sub_dep).subs(sub_2)).is_number:
                 continue
-            cg_index[index_expr.subs(sub_dep).subs(sub_2)] = j, expr.subs(lt,1).subs(sub_dep).subs(sub_2), lt.subs(sub_2), sign.subs(sub_dep).subs(sub_2)
+            cg_index[index_expr.subs(sub_dep).subs(sub_2)] = j, expr.subs(lt, 1).subs(sub_dep).subs(sub_2), lt.subs(sub_2), sign.subs(sub_dep).subs(sub_2)
         if all(i is not None for i in cg_index):
             min_lt = min(*[ abs(term[2]) for term in cg_index ])
             indicies = [ term[0] for term in cg_index]
@@ -616,12 +628,13 @@ def _check_cg_simp(expr, simp, sign, lt, term_list, variables, dep_variables, bu
             [ term_list.pop(i) for i in indicies ]
             for term in cg_index:
                 if abs(term[2]) > min_lt:
-                    term_list.append( (term[2]-min_lt*term[3]) * term[1] )
+                    term_list.append( (term[2] - min_lt*term[3]) * term[1] )
             other_part += min_lt * (sign*simp).subs(sub_1)
         else:
             i += 1
     return term_list, other_part
 
+
 def _check_cg(cg_term, expr, length, sign=None):
     """Checks whether a term matches the given expression"""
     # TODO: Check for symmetries
@@ -636,30 +649,35 @@ def _check_cg(cg_term, expr, length, sign=None):
     if len(matches) == length:
         return matches
 
+
 def _cg_simp_sum(e):
     e = _check_varsh_sum_871_1(e)
     e = _check_varsh_sum_871_2(e)
     e = _check_varsh_sum_872_4(e)
     return e
 
+
 def _check_varsh_sum_871_1(e):
     a = Wild('a')
     alpha = symbols('alpha')
     b = Wild('b')
-    match = e.match(Sum(CG(a,alpha,b,0,a,alpha),(alpha,-a,a)))
+    match = e.match(Sum(CG(a, alpha, b, 0, a, alpha), (alpha, -a, a)))
     if match is not None and len(match) == 2:
-        return ((2*a+1)*KroneckerDelta(b,0)).subs(match)
+        return ((2*a + 1)*KroneckerDelta(b, 0)).subs(match)
     return e
 
+
 def _check_varsh_sum_871_2(e):
     a = Wild('a')
     alpha = symbols('alpha')
     c = Wild('c')
-    match = e.match(Sum((-1)**(a-alpha)*CG(a,alpha,a,-alpha,c,0),(alpha,-a,a)))
+    match = e.match(
+        Sum((-1)**(a - alpha)*CG(a, alpha, a, -alpha, c, 0), (alpha, -a, a)))
     if match is not None and len(match) == 2:
-        return (sqrt(2*a+1)*KroneckerDelta(c,0)).subs(match)
+        return (sqrt(2*a + 1)*KroneckerDelta(c, 0)).subs(match)
     return e
 
+
 def _check_varsh_sum_872_4(e):
     a = Wild('a')
     alpha = Wild('alpha')
@@ -669,14 +687,17 @@ def _check_varsh_sum_872_4(e):
     cp = Wild('cp')
     gamma = Wild('gamma')
     gammap = Wild('gammap')
-    match1 = e.match(Sum(CG(a,alpha,b,beta,c,gamma)*CG(a,alpha,b,beta,cp,gammap),(alpha,-a,a),(beta,-b,b)))
+    match1 = e.match(Sum(CG(a, alpha, b, beta, c, gamma)*CG(
+        a, alpha, b, beta, cp, gammap), (alpha, -a, a), (beta, -b, b)))
     if match1 is not None and len(match1) == 8:
-        return (KroneckerDelta(c,cp)*KroneckerDelta(gamma,gammap)).subs(match1)
-    match2 = e.match(Sum(CG(a,alpha,b,beta,c,gamma)**2,(alpha,-a,a),(beta,-b,b)))
+        return (KroneckerDelta(c, cp)*KroneckerDelta(gamma, gammap)).subs(match1)
+    match2 = e.match(Sum(
+        CG(a, alpha, b, beta, c, gamma)**2, (alpha, -a, a), (beta, -b, b)))
     if match2 is not None and len(match2) == 6:
         return 1
     return e
 
+
 def _cg_list(term):
     if isinstance(term, CG):
         return (term,), 1, 1
