@@ -37,6 +37,7 @@ from sympy.core.compatibility import iterable
 ## Abstract base classes #################################################
 ##########################################################################
 
+
 class Module(object):
     """
     Abstract base class for modules.
@@ -151,6 +152,7 @@ class Module(object):
         """Return the identity homomorphism on ``self``."""
         raise NotImplementedError
 
+
 class ModuleElement(object):
     """
     Base class for module element wrappers.
@@ -252,6 +254,7 @@ class ModuleElement(object):
 ## Free Modules ##########################################################
 ##########################################################################
 
+
 class FreeModuleElement(ModuleElement):
     """Element of a free module. Data stored as a tuple."""
 
@@ -274,6 +277,7 @@ class FreeModuleElement(ModuleElement):
     def __getitem__(self, idx):
         return self.data[idx]
 
+
 class FreeModule(Module):
     """
     Abstract base class for free modules.
@@ -413,12 +417,14 @@ class FreeModule(Module):
         >>> from sympy.abc import x
         >>> from sympy import QQ
         >>> QQ[x].free_module(2).identity_hom()
-        [1, 0]
-        [0, 1] : QQ[x]**2 -> QQ[x]**2
+        Matrix([
+        [1, 0], : QQ[x]**2 -> QQ[x]**2
+        [0, 1]])
         """
         from sympy.polys.agca.homomorphisms import homomorphism
         return homomorphism(self, self, self.basis())
 
+
 class FreeModulePolyRing(FreeModule):
     """
     Free module over a generalized polynomial ring.
@@ -437,7 +443,7 @@ class FreeModulePolyRing(FreeModule):
     """
 
     def __init__(self, ring, rank):
-        from sympy.polys.domains.polynomialring import PolynomialRingBase
+        from sympy.polys.domains.old_polynomialring import PolynomialRingBase
         FreeModule.__init__(self, ring, rank)
         if not isinstance(ring, PolynomialRingBase):
             raise NotImplementedError('This implementation only works over '
@@ -462,6 +468,7 @@ class FreeModulePolyRing(FreeModule):
         """
         return SubModulePolyRing(gens, self, **opts)
 
+
 class FreeModuleQuotientRing(FreeModule):
     """
     Free module over a quotient ring.
@@ -551,6 +558,7 @@ class FreeModuleQuotientRing(FreeModule):
 ## Submodules and subquotients ###########################################
 ##########################################################################
 
+
 class SubModule(Module):
     """
     Base class for submodules.
@@ -656,7 +664,8 @@ class SubModule(Module):
         if not isinstance(other, SubModule):
             raise TypeError('%s is not a SubModule' % other)
         if other.container != self.container:
-            raise ValueError('%s is contained in a different free module' % other)
+            raise ValueError(
+                '%s is contained in a different free module' % other)
         return self._intersect(other, **options)
 
     def module_quotient(self, other, **options):
@@ -692,7 +701,8 @@ class SubModule(Module):
         if not isinstance(other, SubModule):
             raise TypeError('%s is not a SubModule' % other)
         if other.container != self.container:
-            raise ValueError('%s is contained in a different free module' % other)
+            raise ValueError(
+                '%s is contained in a different free module' % other)
         return self._module_quotient(other, **options)
 
     def union(self, other):
@@ -710,7 +720,8 @@ class SubModule(Module):
         if not isinstance(other, SubModule):
             raise TypeError('%s is not a SubModule' % other)
         if other.container != self.container:
-            raise ValueError('%s is contained in a different free module' % other)
+            raise ValueError(
+                '%s is contained in a different free module' % other)
         return self.__class__(self.gens + other.gens, self.container)
 
     def is_zero(self):
@@ -773,7 +784,7 @@ class SubModule(Module):
         """
         if isinstance(other, SubModule):
             return self.container == other.container and \
-                   all(self.contains(x) for x in other.gens)
+                all(self.contains(x) for x in other.gens)
         if isinstance(other, (FreeModule, QuotientModule)):
             return self.container == other and self.is_full_module()
         return False
@@ -887,8 +898,9 @@ class SubModule(Module):
         >>> from sympy.abc import x
         >>> from sympy import QQ
         >>> QQ[x].free_module(2).submodule([x, x]).inclusion_hom()
-        [1, 0]
-        [0, 1] : <[x, x]> -> QQ[x]**2
+        Matrix([
+        [1, 0], : <[x, x]> -> QQ[x]**2
+        [0, 1]])
         """
         return self.container.identity_hom().restrict_domain(self)
 
@@ -899,12 +911,14 @@ class SubModule(Module):
         >>> from sympy.abc import x
         >>> from sympy import QQ
         >>> QQ[x].free_module(2).submodule([x, x]).identity_hom()
-        [1, 0]
-        [0, 1] : <[x, x]> -> <[x, x]>
+        Matrix([
+        [1, 0], : <[x, x]> -> <[x, x]>
+        [0, 1]])
         """
         return self.container.identity_hom().restrict_domain(
             self).restrict_codomain(self)
 
+
 class SubQuotientModule(SubModule):
     """
     Submodule of a quotient module.
@@ -925,7 +939,7 @@ class SubQuotientModule(SubModule):
     Attributes:
 
     - base - base module we are quotient of
-    - killed_module - submodule we are quotienting by
+    - killed_module - submodule used to form the quotient
     """
     def __init__(self, gens, container, **opts):
         SubModule.__init__(self, gens, container)
@@ -933,7 +947,7 @@ class SubQuotientModule(SubModule):
         # XXX it is important for some code below that the generators of base
         #     are in this particular order!
         self.base = self.container.base.submodule(
-                        *[x.data for x in self.gens], **opts).union(self.killed_module)
+            *[x.data for x in self.gens], **opts).union(self.killed_module)
 
     def _contains(self, elem):
         return self.base.contains(elem.data)
@@ -979,14 +993,17 @@ class SubQuotientModule(SubModule):
         >>> from sympy import QQ
         >>> M = (QQ[x].free_module(2) / [(1, x)]).submodule([1, 0])
         >>> M.quotient_hom()
-        [1, 0]
-        [0, 1] : <[1, 0], [1, x]> -> <[1, 0] + <[1, x]>, [1, x] + <[1, x]>>
+        Matrix([
+        [1, 0], : <[1, 0], [1, x]> -> <[1, 0] + <[1, x]>, [1, x] + <[1, x]>>
+        [0, 1]])
         """
         return self.base.identity_hom().quotient_codomain(self.killed_module)
 
 
 _subs0 = lambda x: x[0]
 _subs1 = lambda x: x[1:]
+
+
 class ModuleOrder(ProductOrder):
     """A product monomial order with a zeroth term as module index."""
 
@@ -996,6 +1013,7 @@ class ModuleOrder(ProductOrder):
         else:
             ProductOrder.__init__(self, (o1, _subs0), (o2, _subs1))
 
+
 class SubModulePolyRing(SubModule):
     """
     Submodule of a free module over a generalized polynomial ring.
@@ -1035,12 +1053,12 @@ class SubModulePolyRing(SubModule):
         from sympy.polys.distributedmodules import sdm_groebner, sdm_nf_mora
         if self._gbe is None and extended:
             gb, gbe = sdm_groebner(
-               [self.ring._vector_to_sdm(x, self.order) for x in self.gens],
-               sdm_nf_mora, self.order, self.ring.dom, extended=True)
+                [self.ring._vector_to_sdm(x, self.order) for x in self.gens],
+                sdm_nf_mora, self.order, self.ring.dom, extended=True)
             self._gb, self._gbe = tuple(gb), tuple(gbe)
         if self._gb is None:
             self._gb = tuple(sdm_groebner(
-               [self.ring._vector_to_sdm(x, self.order) for x in self.gens],
+                             [self.ring._vector_to_sdm(x, self.order) for x in self.gens],
                sdm_nf_mora, self.order, self.ring.dom))
         if extended:
             return self._gb, self._gbe
@@ -1057,12 +1075,11 @@ class SubModulePolyRing(SubModule):
                  for x in gb],
                 [self.ring._sdm_to_vector(x, len(self.gens)) for x in gbe])
 
-
     def _contains(self, x):
         from sympy.polys.distributedmodules import sdm_zero, sdm_nf_mora
         return sdm_nf_mora(self.ring._vector_to_sdm(x, self.order),
                            self._groebner(), self.order, self.ring.dom) == \
-               sdm_zero()
+            sdm_zero()
 
     def _syzygies(self):
         """Compute syzygies. See [SCA, algorithm 2.5.4]."""
@@ -1077,7 +1094,7 @@ class SubModulePolyRing(SubModule):
         Rkr = self.ring.free_module(r + k)
         newgens = []
         for j, f in enumerate(self.gens):
-            m = [0]*(r+k)
+            m = [0]*(r + k)
             for i, v in enumerate(f):
                 m[i] = f[i]
             for i in range(k):
@@ -1091,7 +1108,8 @@ class SubModulePolyRing(SubModule):
         G = F._groebner_vec()
 
         # Third bullet point: G0 = G intersect the new k components
-        G0 = [x[r:] for x in G if all(y == self.ring.convert(0) for y in x[:r])]
+        G0 = [x[r:] for x in G if all(y == self.ring.convert(0)
+                                      for y in x[:r])]
 
         # Fourth and fifth bullet points: we are done
         return G0
@@ -1100,7 +1118,8 @@ class SubModulePolyRing(SubModule):
         """Expression in terms of generators. See [SCA, 2.8.1]."""
         # NOTE: if gens is a standard basis, this can be done more efficiently
         M = self.ring.free_module(self.rank).submodule(*((e,) + self.gens))
-        S = M.syzygy_module(order="ilex", TOP=False) # We want decreasing order!
+        S = M.syzygy_module(
+            order="ilex", TOP=False)  # We want decreasing order!
         G = S._groebner_vec()
         # This list cannot not be empty since e is an element
         e = list(filter(lambda x: self.ring.is_unit(x[0]), G))[0]
@@ -1117,15 +1136,15 @@ class SubModulePolyRing(SubModule):
         if NF is None:
             NF = sdm_nf_mora
         return self.container.convert(self.ring._sdm_to_vector(NF(
-                self.ring._vector_to_sdm(x, self.order), self._groebner(),
-                    self.order, self.ring.dom),
-                self.rank))
+            self.ring._vector_to_sdm(x, self.order), self._groebner(),
+            self.order, self.ring.dom),
+            self.rank))
 
     def _intersect(self, other, relations=False):
         # See: [SCA, section 2.8.2]
         fi = self.gens
         hi = other.gens
-        r  = self.rank
+        r = self.rank
         ci = [[0]*(2*r) for _ in range(r)]
         for k in range(r):
             ci[k][k] = 1
@@ -1135,8 +1154,8 @@ class SubModulePolyRing(SubModule):
         syz = self.ring.free_module(2*r).submodule(*(ci + di + ei))._syzygies()
         nonzero = [x for x in syz if any(y != self.ring.zero for y in x[:r])]
         res = self.container.submodule(*([-y for y in x[:r]] for x in nonzero))
-        reln1 = [x[r:r+len(fi)] for x in nonzero]
-        reln2 = [x[r+len(fi):] for x in nonzero]
+        reln1 = [x[r:r + len(fi)] for x in nonzero]
+        reln2 = [x[r + len(fi):] for x in nonzero]
         if relations:
             return res, reln1, reln2
         return res
@@ -1173,6 +1192,7 @@ class SubModulePolyRing(SubModule):
         return reduce(lambda x, y: x.intersect(y),
             (self._module_quotient(self.container.submodule(x)) for x in other.gens))
 
+
 class SubModuleQuotientRing(SubModule):
     """
     Class for submodules of free modules over quotient rings.
@@ -1204,16 +1224,17 @@ class SubModuleQuotientRing(SubModule):
 
     def _syzygies(self):
         return [tuple(self.ring.convert(y, self.quot.ring) for y in x)
-                    for x in self.quot._syzygies()]
+                for x in self.quot._syzygies()]
 
     def _in_terms_of_generators(self, elem):
-        return [self.ring.convert(x, self.quot.ring) for x in \
+        return [self.ring.convert(x, self.quot.ring) for x in
             self.quot._in_terms_of_generators(self.container.lift(elem))]
 
 ##########################################################################
 ## Quotient Modules ######################################################
 ##########################################################################
 
+
 class QuotientModuleElement(ModuleElement):
     """Element of a quotient module."""
 
@@ -1225,6 +1246,7 @@ class QuotientModuleElement(ModuleElement):
         from sympy import sstr
         return repr(self.data) + " + " + repr(self.module.killed_module)
 
+
 class QuotientModule(Module):
     """
     Class for quotient modules.
@@ -1235,7 +1257,7 @@ class QuotientModule(Module):
     Attributes:
 
     - base - the base module we are a quotient of
-    - killed_module - the submodule we are quotienting by
+    - killed_module - the submodule used to form the quotient
     - rank of the base
     """
 
@@ -1284,7 +1306,7 @@ class QuotientModule(Module):
         """
         if isinstance(other, QuotientModule):
             return self.killed_module == other.killed_module and \
-                   self.base.is_submodule(other.base)
+                self.base.is_submodule(other.base)
         if isinstance(other, SubQuotientModule):
             return other.container == self
         return False
@@ -1333,8 +1355,9 @@ class QuotientModule(Module):
         >>> from sympy import QQ
         >>> M = QQ[x].free_module(2) / [(1, 2), (1, x)]
         >>> M.identity_hom()
-        [1, 0]
-        [0, 1] : QQ[x]**2/<[1, 2], [1, x]> -> QQ[x]**2/<[1, 2], [1, x]>
+        Matrix([
+        [1, 0], : QQ[x]**2/<[1, 2], [1, x]> -> QQ[x]**2/<[1, 2], [1, x]>
+        [0, 1]])
         """
         return self.base.identity_hom().quotient_codomain(
             self.killed_module).quotient_domain(self.killed_module)
@@ -1350,8 +1373,9 @@ class QuotientModule(Module):
         >>> from sympy import QQ
         >>> M = QQ[x].free_module(2) / [(1, 2), (1, x)]
         >>> M.quotient_hom()
-        [1, 0]
-        [0, 1] : QQ[x]**2 -> QQ[x]**2/<[1, 2], [1, x]>
+        Matrix([
+        [1, 0], : QQ[x]**2 -> QQ[x]**2/<[1, 2], [1, x]>
+        [0, 1]])
         """
         return self.base.identity_hom().quotient_codomain(
             self.killed_module)
